// Copyright (C) 2005-2007 Stefan Bauer <yoltia-maintain@freenet.de>

// This file is part of Yoltia.
//
// Yoltia is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License Version 2
// as published by the Free Software Foundation.
//    
// Yoltia is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Yoltia; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#include "scsizechanger.hpp"
#include <qlayout.h>
#include <qstringlist.h>

SCSizeChanger::SCSizeChanger(int _stWidth , int _stHeight , QWidget* parent) : QWidget(parent , "sizeChanger" , 0) {
  stWidth = _stWidth;
  stHeight = _stHeight;
  absWidth = stWidth;
  absHeight = stHeight;
  width = new QSpinBox(1 , 8200 , 1 , this , "width");
  height = new QSpinBox(1 , 8200 , 1 , this , "height");
  width->setValue(absWidth);
  height->setValue(absHeight);
  QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding , QSizePolicy::Fixed);
  width->setSizePolicy(sizePolicy);
  height->setSizePolicy(sizePolicy);
  connect(width , SIGNAL(valueChanged(int)) , this , SLOT(widthChanged(int)));
  connect(height , SIGNAL(valueChanged(int)) , this , SLOT(heightChanged(int)));
  QGridLayout *container = new QGridLayout(this , 0 , 0 , 0 , 10 , "container");
  container->addWidget(new QLabel(width , tr("&Width:") , this , "descrWidth") , 0 , 0);
  container->addWidget(new QLabel(height , tr("&Height:") , this , "descrHeight") , 1 , 0);
  container->addWidget(width , 0 , 1);
  container->addWidget(height , 1 , 1);
  widthUnit = new QListBox(this , "widthUnit");
  heightUnit = new QListBox(this , "heightUnit");
  widthUnit->insertStringList(QStringList::split("-" , "Pixel-Promille"));
  heightUnit->insertStringList(QStringList::split("-" , "Pixel-Promille"));
  widthUnit->setCurrentItem(0);
  heightUnit->setCurrentItem(0);
  connect(widthUnit , SIGNAL(highlighted(int)) , this , SLOT(widthUnitChanged(int)));
  connect(heightUnit , SIGNAL(highlighted(int)) , this , SLOT(heightUnitChanged(int)));
  sizePolicy = QSizePolicy(QSizePolicy::Minimum , QSizePolicy::Minimum);
  widthUnit->setSizePolicy(sizePolicy);
  heightUnit->setSizePolicy(sizePolicy);
  container->addWidget(widthUnit , 0 , 2);
  container->addWidget(heightUnit , 1 , 2);
  actRel = new QLabel(tr("Current realtion: %1").arg(QString::number((double) height->value() / (double) width->value())) , this , "actRel");
  keepRel = new QCheckBox(tr("&Keep relation") , this , "keepRel");
  container->addMultiCellWidget(actRel , 2 , 2 , 0 , 2);
  container->addMultiCellWidget(keepRel , 3 , 3 , 0 , 2);
  
}

void SCSizeChanger::heightChanged(int newHeight) {
  if (heightUnit->currentItem())	//Einheit der H�he == Promille?
      absHeight = qRound(stHeight * newHeight / 1000.0);
    else
      absHeight = newHeight;
  if (keepRel->isChecked()) {
    double rel = (double) absHeight / (double) stHeight;
    int newWidth;
    if (widthUnit->currentItem())	//Einheit der Breite == Promille?
	newWidth = qRound(1000.0 * rel);
      else	//sonst (Einheit der Breite == Pixel)
	newWidth = qRound(stWidth * rel);
    width->setValue(newWidth);
  }
  actRel->setText(tr("Current realtion: %1").arg((double) absHeight / (double) absWidth));
  emit sizeChanged();
}

void SCSizeChanger::widthChanged(int newWidth) {
  if (widthUnit->currentItem())	//Einheit der Breite == Promille?
      absWidth = qRound(stWidth * newWidth / 1000.0);
    else
      absWidth = newWidth;
  if (keepRel->isChecked()) {
    double rel = (double) absWidth / (double) stWidth;
    int newHeight;
    if (heightUnit->currentItem())	//Einheit der H�he == Promille?
	newHeight = qRound(1000.0 * rel);
      else	//sonst (Einheit der H�he == Pixel)
	newHeight = qRound(stHeight * rel);
    height->setValue(newHeight);
  }
  actRel->setText(tr("Current realtion: %1").arg((double) absHeight / (double) absWidth));
  emit sizeChanged();
}

void SCSizeChanger::widthUnitChanged(int index){
  int newWidth , minWidth , maxWidth;
  if (index) {	//Einheit: Promille
      newWidth = qRound(1000.0 * absWidth / stWidth);
      minWidth = qRound(1000.0 / stWidth);
      maxWidth = qRound(8200000.0 / stWidth);
    } else {	//sonst (Einheit == Pixel)
      newWidth = absWidth;
      minWidth = 1;
      maxWidth = 8200;
  }
  width->setRange(minWidth , maxWidth);
  width->setValue(newWidth);
}

void SCSizeChanger::heightUnitChanged(int index) {
  int newHeight , minHeight , maxHeight;
  if (index) {	//Einheit: Promille
      newHeight = qRound(1000.0 * absHeight / stHeight);
      minHeight = qRound(1000.0 / stHeight);
      maxHeight = qRound(8200000.0 / stHeight);
    } else {	//sonst (Einheit == Pixel)
      newHeight = absHeight;
      minHeight = 1;
      maxHeight = 8200;
  }
  height->setRange(minHeight , maxHeight);
  height->setValue(newHeight);
}
