// Copyright (C) 2005-2007 Stefan Bauer <yoltia-maintain@freenet.de>

// This file is part of Yoltia.
//
// Yoltia is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License Version 2
// as published by the Free Software Foundation.
//    
// Yoltia is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Yoltia; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#include "srgbanp.hpp"
#include <qpushbutton.h>
#include <qlayout.h>
#include <qlabel.h>

SRGBAnp::SRGBAnp(QWidget *parent , QImage *datenAddr , QImage *backupAddr) : QDialog(parent , "RGBAnp" , true) {
  daten = datenAddr;
  backup = backupAddr;
  QGridLayout *container = new QGridLayout(this , 4 , 3 , 10 , -1 , "container");
  redAdj = new QSlider(-255 , 255 , 1 , 0 , Qt::Horizontal , this , "redAdj");
  greenAdj = new QSlider(-255 , 255 , 1 , 0 , Qt::Horizontal , this , "greenAdj");
  blueAdj = new QSlider(-255 , 255 , 1 , 0 , Qt::Horizontal , this , "blueAdj");
  QPushButton *redNuller = new QPushButton(tr("&Start value") , this , "redNuller");
  QPushButton *greenNuller = new QPushButton(tr("&Start value") , this , "greenNuller");
  QPushButton *blueNuller = new QPushButton(tr("&Start value") , this , "blueNuller");
  connect(redAdj , SIGNAL(valueChanged(int)) , this , SLOT(anpassen()));
  connect(greenAdj , SIGNAL(valueChanged(int)) , this , SLOT(anpassen()));
  connect(blueAdj , SIGNAL(valueChanged(int)) , this , SLOT(anpassen()));
  connect(redNuller , SIGNAL(clicked()) , this , SLOT(nullRed()));
  connect(greenNuller , SIGNAL(clicked()) , this , SLOT(nullGreen()));
  connect(blueNuller , SIGNAL(clicked()) , this , SLOT(nullBlue()));
  container->addWidget(new QLabel(redAdj , tr("&Red:") , this , "descrR") , 0 , 0);
  container->addWidget(new QLabel(greenAdj , tr("&Green:") , this , "descrG") , 1 , 0);
  container->addWidget(new QLabel(blueAdj , tr("&Blue:") , this , "descrB") , 2 , 0);
  container->addWidget(redAdj , 0 , 1);
  container->addWidget(greenAdj , 1 , 1);
  container->addWidget(blueAdj , 2 , 1);
  container->addWidget(redNuller , 0 , 2);
  container->addWidget(greenNuller , 1 , 2);
  container->addWidget(blueNuller , 2 , 2);
  QPushButton *ok = new QPushButton(tr("&Finished") , this , "ok");
  ok->setDefault(true);
  connect(ok , SIGNAL(clicked()) , this , SLOT(accept()));
  container->addMultiCellWidget(ok , 3 , 3 , 0 , 2);
  setCaption(tr("RGB adjust"));
}

void SRGBAnp::anpassen() {
  QRgb alteFarbe;
  if (backup->depth() > 8)	//Bild benutzt keine Colortable?
      for (int x = 0 ; x < backup->width() ; x++)
	for (int y = 0 ; y < backup->height() ; y++) {
	  alteFarbe = backup->pixel(x , y);
	  daten->setPixel(x , y , qRgb(QMAX(QMIN(qRed(alteFarbe) + redAdj->value() , 255) , 0) , QMAX(QMIN(qGreen(alteFarbe) + greenAdj->value() , 255) , 0) , QMAX(QMIN(qBlue(alteFarbe) + blueAdj->value(), 255) , 0)));
	}
    else
      for (int index = 0 ; index < backup->numColors() ; index++) {
	alteFarbe = backup->color(index);
	daten->setColor(index , qRgb(QMAX(QMIN(qRed(alteFarbe) + redAdj->value() , 255) , 0) , QMAX(QMIN(qGreen(alteFarbe) + greenAdj->value() , 255) , 0) , QMAX(QMIN(qBlue(alteFarbe) + blueAdj->value(), 255) , 0)));
      }
  emit modified();
}

