// Copyright (C) 2005-2007 Stefan Bauer <yoltia-maintain@freenet.de>

// This file is part of Yoltia.
//
// Yoltia is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License Version 2
// as published by the Free Software Foundation.
//    
// Yoltia is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Yoltia; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#include "stiefenkonv.hpp"
#include <qpushbutton.h>
#include <qlayout.h>
#include <qlabel.h>

STiefenkonv::STiefenkonv(QWidget *parent , QImage *datenAddr , QImage *backupAddr) : QDialog(parent , "tiefenkonv" , true) {
  daten = datenAddr;
  backup = backupAddr;
  QGridLayout *container = new QGridLayout(this , 3 , 2 , 10 , -1 , "container");
  tiefenList = new QListBox(this , "tiefenList");
  ditherList = new QListBox(this , "ditherList");
  tiefenList->insertStringList(QStringList::split("-" , "1 Bit / Pixel-8 Bit / Pixel-32 Bit / Pixel"));
  ditherList->insertStringList(QStringList::split("-" , tr("Diffuse Dither-Ordered Dither-No dither")));
  tiefenList->setCurrentItem(2);
  ditherList->setCurrentItem(2);
  connect(tiefenList , SIGNAL(selectionChanged()) , this , SLOT(createPreview()));
  connect(ditherList , SIGNAL(selectionChanged()) , this , SLOT(createPreview()));
  container->addWidget(tiefenList, 1 , 0);
  container->addWidget(ditherList , 1 , 1);
  container->addWidget(new QLabel(tiefenList , tr("&Color depth:") , this , "descrDepth") , 0 , 0);
  container->addWidget(new QLabel(ditherList , tr("&Dither:") , this , "descrDither") , 0 , 1);
  QPushButton *ok = new QPushButton(tr("&Finished") , this , "ok");
  ok->setDefault(true);
  connect(ok , SIGNAL(clicked()) , this , SLOT(accept()));
  container->addMultiCellWidget(ok , 2 , 2 , 0 , 1);
  setCaption(tr("Depth conversion"));
}

void STiefenkonv::createPreview() {
  uchar tiefe = 1;
  switch (tiefenList->currentItem()) {
    case 1 :
      tiefe = 8;
      break;
    case 2 :
      tiefe = 32;
    default :
      ;
  }
  int dither = Qt::DiffuseDither;
  switch (ditherList->currentItem()) {
    case 1 :
      dither = Qt::OrderedDither;
      break;
    case 2 :
      dither = Qt::ThresholdDither;
    default :
      ;
  }
  *daten = backup->convertDepth(tiefe , dither);
  emit modified();
}
