// Copyright (C) 2005-2007 Stefan Bauer <yoltia-maintain@freenet.de>

// This file is part of Yoltia.
//
// Yoltia is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License Version 2
// as published by the Free Software Foundation.
//    
// Yoltia is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Yoltia; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#ifndef SPIC_HPP
#define SPIC_HPP

#include <qwidget.h>
#include <qimage.h>
#include <qpixmap.h>
#include "smark.hpp"

class SPic : public QWidget {
  Q_OBJECT
  public :
    SPic(QWidget *parent);
    double zoom;
    void killMark();	//Markierung zerstren
    QImage bilddaten;	//Objekt um Bild zu modifizieren
    QPixmap drawdaten;	//Objekt um Bild zu zeichnen (gezoomt)
    int markX;	//markierter Bereich (relativ zu bilddaten)
    int markY;
    int markB;
    int markH;
    bool existsFixedMark();
  signals :
    void markChanged4P(const QString &);	//bermitteln des Markierungsbereiches
    void MPIChanged4P(const QString &);	//bermitteln der Mauspixelinformation
  private :
    SMark *mark;	//Markierungswidget
    int fixX;	//Fixkoordinaten zum Editieren der Markierung (relativ zu bilddaten)
    int fixY;
    QRect bildrect;	//Bildrechteck (relativ zu this)
    int mapX(const int x , const bool grenzen = true) const;	//Wert relativ zu this auf relativ zu bilddaten mappen
    int mapY(const int y , const bool grenzen = true) const;
    int divX;	//Abstand des Maus-X-Wertes von der oberen Kante (fr Markierungsverschiebung)
    int divY;	//Abstand des Maus-Y-Wertes von der linken Kante
  protected :
    void paintEvent(QPaintEvent *);	//drawdaten auf Widget zeichnen
    void mousePressEvent(QMouseEvent *maus);	//Beginn, Ende, nderung oder Zerstrung der Markierung
    void mouseMoveEvent(QMouseEvent *maus);	//Editieren der Markierung in der 1. Phase
    void leaveEvent(QEvent *);	//bermitteln leerer Mauspixelinformation
  private slots :
    void registerClick(SEditReg editReg);
};

inline bool SPic::existsFixedMark() {
  return mark->mode == fixed;
}

inline void SPic::killMark() {
  if (mark->mode != none) {	//Markierung existent?
    mark->mode = none;
    mark->hide();
    emit markChanged4P(0);
  }
}

#endif
